
/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton implementation for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.4.1"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Copy the first part of user declarations.  */

/* Line 189 of yacc.c  */
#line 1 "parser.y"

/*
 *
 *	The slony_logshipper command language grammar
 *
 *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 *	Author: Jan Wieck, Afilias USA INC.
 *
 *	$Id: parser.y,v 1.3.2.2 2010-05-27 20:38:32 ssinger Exp $
 *-------------------------------------------------------------------------
 */

#include "config.h"
#include "postgres.h"
#include "libpq-fe.h"
#include "slony_logshipper.h"
#include "../parsestatements/scanner.h"

#include "scan.h"

extern int STMTS[MAXSTATEMENTS];


/*
 * Global data
 */
char   *current_file = "<stdin>";
#ifdef DEBUG
int yydebug=1;
#endif




/* Line 189 of yacc.c  */
#line 108 "y.tab.c"

/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* Enabling the token table.  */
#ifndef YYTOKEN_TABLE
# define YYTOKEN_TABLE 0
#endif


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     K_LOGFILE = 258,
     K_MAX = 259,
     K_ARCHIVES = 260,
     K_ANALYZE = 261,
     K_AND = 262,
     K_ARCHIVE = 263,
     K_ARCHIVE_COMMENT = 264,
     K_CLUSTER = 265,
     K_COMMAND = 266,
     K_COMMIT = 267,
     K_CONF_COMMENT = 268,
     K_COPY = 269,
     K_DATABASE = 270,
     K_DELETE = 271,
     K_DESTINATION = 272,
     K_DIR = 273,
     K_ERROR = 274,
     K_EXEC_DDL = 275,
     K_FROM = 276,
     K_IGNORE = 277,
     K_INSERT = 278,
     K_INTO = 279,
     K_NAME = 280,
     K_NAMESPACE = 281,
     K_NULL = 282,
     K_ONLY = 283,
     K_POST = 284,
     K_PRE = 285,
     K_PROCESSING = 286,
     K_RENAME = 287,
     K_REPLICA = 288,
     K_SELECT = 289,
     K_SESSION_ROLE = 290,
     K_SET = 291,
     K_START = 292,
     K_START_ARCHIVE = 293,
     K_START_CONFIG = 294,
     K_TABLE = 295,
     K_TO = 296,
     K_TRANSACTION = 297,
     K_UPDATE = 298,
     K_VACUUM = 299,
     K_VALUES = 300,
     K_WHERE = 301,
     T_COPYDATA = 302,
     T_COPYDATA_PART = 303,
     T_COPYEND = 304,
     T_IDENT = 305,
     T_LITERAL = 306,
     T_LITERAL_PART = 307,
     T_NUMBER = 308,
     T_TRACKING_FUNCTION = 309,
     T_FINISH_FUNCTION = 310,
     T_SEQSETVAL_FUNCTION = 311,
     T_PGSETVAL_FUNCTION = 312
   };
#endif
/* Tokens.  */
#define K_LOGFILE 258
#define K_MAX 259
#define K_ARCHIVES 260
#define K_ANALYZE 261
#define K_AND 262
#define K_ARCHIVE 263
#define K_ARCHIVE_COMMENT 264
#define K_CLUSTER 265
#define K_COMMAND 266
#define K_COMMIT 267
#define K_CONF_COMMENT 268
#define K_COPY 269
#define K_DATABASE 270
#define K_DELETE 271
#define K_DESTINATION 272
#define K_DIR 273
#define K_ERROR 274
#define K_EXEC_DDL 275
#define K_FROM 276
#define K_IGNORE 277
#define K_INSERT 278
#define K_INTO 279
#define K_NAME 280
#define K_NAMESPACE 281
#define K_NULL 282
#define K_ONLY 283
#define K_POST 284
#define K_PRE 285
#define K_PROCESSING 286
#define K_RENAME 287
#define K_REPLICA 288
#define K_SELECT 289
#define K_SESSION_ROLE 290
#define K_SET 291
#define K_START 292
#define K_START_ARCHIVE 293
#define K_START_CONFIG 294
#define K_TABLE 295
#define K_TO 296
#define K_TRANSACTION 297
#define K_UPDATE 298
#define K_VACUUM 299
#define K_VALUES 300
#define K_WHERE 301
#define T_COPYDATA 302
#define T_COPYDATA_PART 303
#define T_COPYEND 304
#define T_IDENT 305
#define T_LITERAL 306
#define T_LITERAL_PART 307
#define T_NUMBER 308
#define T_TRACKING_FUNCTION 309
#define T_FINISH_FUNCTION 310
#define T_SEQSETVAL_FUNCTION 311
#define T_PGSETVAL_FUNCTION 312




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 214 of yacc.c  */
#line 38 "parser.y"

	int32		ival;
	char	   *str;
	AttElem	   *att_elem;
	AttElemList	*att_elem_list;
	SlonDString *dstring;



/* Line 214 of yacc.c  */
#line 268 "y.tab.c"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif


/* Copy the second part of user declarations.  */


/* Line 264 of yacc.c  */
#line 280 "y.tab.c"

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#elif (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
typedef signed char yytype_int8;
#else
typedef short int yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(e) ((void) (e))
#else
# define YYUSE(e) /* empty */
#endif

/* Identity function, used to suppress warnings about constant conditions.  */
#ifndef lint
# define YYID(n) (n)
#else
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static int
YYID (int yyi)
#else
static int
YYID (yyi)
    int yyi;
#endif
{
  return yyi;
}
#endif

#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#     ifndef _STDLIB_H
#      define _STDLIB_H 1
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (YYID (0))
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined _STDLIB_H \
       && ! ((defined YYMALLOC || defined malloc) \
	     && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef _STDLIB_H
#    define _STDLIB_H 1
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
	 || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  YYSIZE_T yyi;				\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (YYID (0))
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
	Stack = &yyptr->Stack_alloc;					\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (YYID (0))

#endif

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  8
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   258

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  64
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  58
/* YYNRULES -- Number of rules.  */
#define YYNRULES  131
/* YYNRULES -- Number of states.  */
#define YYNSTATES  284

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   312

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      61,    63,     2,     2,    62,     2,    60,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,    58,
       2,    59,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const yytype_uint16 yyprhs[] =
{
       0,     0,     3,     5,     7,    11,    13,    16,    18,    20,
      22,    24,    26,    28,    30,    32,    34,    36,    38,    44,
      50,    56,    61,    67,    73,    78,    85,    92,   103,   110,
     117,   123,   128,   133,   139,   143,   154,   156,   158,   161,
     163,   165,   167,   169,   171,   173,   175,   177,   179,   181,
     183,   185,   187,   189,   192,   206,   208,   212,   221,   224,
     228,   237,   239,   240,   242,   243,   254,   256,   259,   261,
     264,   266,   268,   270,   272,   276,   279,   283,   287,   294,
     300,   309,   311,   322,   324,   335,   337,   339,   341,   344,
     346,   348,   350,   352,   354,   356,   358,   360,   362,   364,
     366,   368,   370,   372,   374,   376,   378,   380,   382,   384,
     386,   388,   390,   392,   394,   396,   398,   400,   402,   404,
     406,   408,   410,   412,   414,   416,   418,   421,   423,   425,
     428,   430
};

/* YYRHS -- A `-1'-separated list of the rules' RHS.  */
static const yytype_int8 yyrhs[] =
{
      65,     0,    -1,    66,    -1,    79,    -1,    39,    58,    67,
      -1,    68,    -1,    67,    68,    -1,    13,    -1,    69,    -1,
      70,    -1,    71,    -1,    72,    -1,    73,    -1,    74,    -1,
      75,    -1,    76,    -1,    77,    -1,    78,    -1,     8,    18,
      59,   118,    58,    -1,    17,    18,    59,   118,    58,    -1,
      17,    15,    59,   118,    58,    -1,     3,    59,   118,    58,
      -1,     4,     5,    59,   115,    58,    -1,    10,    25,    59,
     118,    58,    -1,    22,    26,   116,    58,    -1,    22,    40,
     116,    60,   116,    58,    -1,    32,    26,   116,    41,   116,
      58,    -1,    32,    40,   116,    60,   116,    41,   116,    60,
     116,    58,    -1,    30,    31,    11,    59,   118,    58,    -1,
      29,    31,    11,    59,   118,    58,    -1,    19,    11,    59,
     118,    58,    -1,    38,    58,    80,    85,    -1,   113,    81,
      82,    83,    -1,    36,    35,    41,    33,    58,    -1,    37,
      42,    58,    -1,    34,   116,    60,    84,    61,   118,    62,
     118,    63,    58,    -1,    54,    -1,    86,    -1,    85,    86,
      -1,   114,    -1,    87,    -1,    88,    -1,    90,    -1,    92,
      -1,    95,    -1,    96,    -1,   100,    -1,   106,    -1,   108,
      -1,   110,    -1,   112,    -1,   104,    -1,   105,    -1,    12,
      58,    -1,    23,    24,   116,    60,   116,    61,   101,    63,
      45,    61,    89,    63,    58,    -1,   118,    -1,    89,    62,
     118,    -1,    43,    28,   116,    60,   116,    91,   102,    58,
      -1,    36,   103,    -1,    91,    62,   103,    -1,    16,    21,
      93,   116,    60,   116,    94,    58,    -1,    28,    -1,    -1,
     102,    -1,    -1,    14,   116,    60,   116,    61,   101,    63,
      21,   116,    58,    -1,    98,    -1,    97,    98,    -1,    99,
      -1,    97,    99,    -1,    47,    -1,    48,    -1,    49,    -1,
     116,    -1,   101,    62,   116,    -1,    46,   103,    -1,   102,
       7,   103,    -1,   116,    59,   118,    -1,    44,     6,   116,
      60,   116,    58,    -1,     6,   116,    60,   116,    58,    -1,
      34,   116,    60,   107,    61,   115,    63,    58,    -1,    55,
      -1,    34,   116,    60,   109,    61,   115,    62,   118,    63,
      58,    -1,    56,    -1,    34,   116,    60,   111,    61,   118,
      62,   118,    63,    58,    -1,    57,    -1,    20,    -1,   114,
      -1,   113,   114,    -1,     9,    -1,    53,    -1,    50,    -1,
     117,    -1,    39,    -1,    38,    -1,     8,    -1,     5,    -1,
      10,    -1,    12,    -1,    14,    -1,    15,    -1,    16,    -1,
      17,    -1,    18,    -1,    19,    -1,    22,    -1,    23,    -1,
       3,    -1,     4,    -1,    25,    -1,    26,    -1,    29,    -1,
      30,    -1,    31,    -1,    32,    -1,    36,    -1,    37,    -1,
      42,    -1,    43,    -1,    44,    -1,    45,    -1,    54,    -1,
      55,    -1,    56,    -1,    57,    -1,   121,    -1,   119,   121,
      -1,    27,    -1,   120,    -1,   119,   120,    -1,    52,    -1,
      51,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   136,   136,   137,   140,   144,   145,   148,   149,   150,
     151,   152,   153,   154,   155,   156,   157,   158,   161,   170,
     179,   188,   197,   203,   212,   223,   235,   247,   263,   277,
     291,   311,   316,   322,   330,   337,   371,   383,   384,   387,
     388,   389,   390,   391,   392,   393,   394,   395,   396,   397,
     398,   399,   400,   403,   410,   451,   465,   481,   521,   531,
     539,   573,   578,   583,   588,   593,   624,   634,   649,   660,
     669,   675,   681,   688,   702,   718,   728,   737,   749,   778,
     807,   824,   836,   854,   866,   885,   897,   945,   946,   949,
     967,   973,   983,   995,   995,   996,   997,   998,   999,  1000,
    1001,  1002,  1003,  1004,  1005,  1006,  1007,  1008,  1009,  1010,
    1011,  1012,  1013,  1014,  1015,  1016,  1017,  1018,  1019,  1020,
    1021,  1022,  1023,  1024,  1025,  1028,  1032,  1045,  1051,  1061,
    1070,  1075
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "K_LOGFILE", "K_MAX", "K_ARCHIVES",
  "K_ANALYZE", "K_AND", "K_ARCHIVE", "K_ARCHIVE_COMMENT", "K_CLUSTER",
  "K_COMMAND", "K_COMMIT", "K_CONF_COMMENT", "K_COPY", "K_DATABASE",
  "K_DELETE", "K_DESTINATION", "K_DIR", "K_ERROR", "K_EXEC_DDL", "K_FROM",
  "K_IGNORE", "K_INSERT", "K_INTO", "K_NAME", "K_NAMESPACE", "K_NULL",
  "K_ONLY", "K_POST", "K_PRE", "K_PROCESSING", "K_RENAME", "K_REPLICA",
  "K_SELECT", "K_SESSION_ROLE", "K_SET", "K_START", "K_START_ARCHIVE",
  "K_START_CONFIG", "K_TABLE", "K_TO", "K_TRANSACTION", "K_UPDATE",
  "K_VACUUM", "K_VALUES", "K_WHERE", "T_COPYDATA", "T_COPYDATA_PART",
  "T_COPYEND", "T_IDENT", "T_LITERAL", "T_LITERAL_PART", "T_NUMBER",
  "T_TRACKING_FUNCTION", "T_FINISH_FUNCTION", "T_SEQSETVAL_FUNCTION",
  "T_PGSETVAL_FUNCTION", "';'", "'='", "'.'", "'('", "','", "')'",
  "$accept", "valid_input", "configuration_file", "conf_stmts",
  "conf_stmt", "conf_archive_dir", "conf_dest_dir", "conf_dest_database",
  "conf_logfile", "conf_maxarchives", "conf_clustername",
  "conf_rename_object", "conf_preprocess", "conf_postprocess",
  "conf_errorcommand", "archive_file", "arch_hdr", "arch_session_role",
  "arch_start_trans", "arch_tracking", "arch_tracking_func", "arch_stmts",
  "arch_stmt", "arch_commit", "arch_insert", "arch_ins_vals",
  "arch_update", "arch_upd_set", "arch_delete", "arch_delete_only",
  "arch_delete_qual", "arch_copy", "arch_copydata", "arch_copydata_parts",
  "arch_copydata_fin", "arch_copydata_part", "arch_copyend",
  "arch_attr_list", "arch_qualification", "arch_ident_eq_lit",
  "arch_vacuum", "arch_analyze", "arch_finishtable", "arch_finish_func",
  "arch_seqsetval", "arch_seqsetval_func", "arch_pgsetval",
  "arch_pgsetval_func", "arch_exec_ddl", "arch_comments", "arch_comment",
  "num", "ident", "ident_keywords", "literal", "literal_parts",
  "literal_part", "literal_final", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,    59,    61,
      46,    40,    44,    41
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    64,    65,    65,    66,    67,    67,    68,    68,    68,
      68,    68,    68,    68,    68,    68,    68,    68,    69,    70,
      71,    72,    73,    74,    75,    75,    75,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,    85,    85,    86,
      86,    86,    86,    86,    86,    86,    86,    86,    86,    86,
      86,    86,    86,    87,    88,    89,    89,    90,    91,    91,
      92,    93,    93,    94,    94,    95,    96,    96,    97,    97,
      98,    99,   100,   101,   101,   102,   102,   103,   104,   105,
     106,   107,   108,   109,   110,   111,   112,   113,   113,   114,
     115,   116,   116,   117,   117,   117,   117,   117,   117,   117,
     117,   117,   117,   117,   117,   117,   117,   117,   117,   117,
     117,   117,   117,   117,   117,   117,   117,   117,   117,   117,
     117,   117,   117,   117,   117,   118,   118,   118,   119,   119,
     120,   121
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     1,     1,     3,     1,     2,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     5,     5,
       5,     4,     5,     5,     4,     6,     6,    10,     6,     6,
       5,     4,     4,     5,     3,    10,     1,     1,     2,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     2,    13,     1,     3,     8,     2,     3,
       8,     1,     0,     1,     0,    10,     1,     2,     1,     2,
       1,     1,     1,     1,     3,     2,     3,     3,     6,     5,
       8,     1,    10,     1,    10,     1,     1,     1,     2,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     2,     1,     1,     2,
       1,     1
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,     0,     0,     0,     2,     3,     0,     0,     1,    89,
       0,     0,    87,     0,     0,     0,     0,     7,     0,     0,
       0,     0,     0,     0,     4,     5,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,     0,     0,     0,     0,
      86,     0,     0,     0,     0,    70,    71,    72,    31,    37,
      40,    41,    42,    43,    44,    45,     0,    66,    68,    46,
      51,    52,    47,    48,    49,    50,    39,     0,     0,    88,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     6,   107,   108,    96,    95,    97,    98,
      99,   100,   101,   102,   103,   104,   105,   106,   109,   110,
     111,   112,   113,   114,   115,   116,    94,    93,   117,   118,
     119,   120,    91,   121,   122,   123,   124,     0,    92,    53,
       0,    62,     0,     0,     0,     0,    38,    67,    69,     0,
       0,     0,   127,   131,   130,     0,     0,   128,   125,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    61,     0,     0,     0,     0,     0,     0,
       0,     0,    32,    21,   129,   126,    90,     0,     0,     0,
       0,     0,     0,    24,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    81,    83,    85,     0,     0,     0,     0,
       0,     0,    34,     0,    22,    18,    23,    20,    19,    30,
       0,     0,     0,     0,     0,    79,     0,     0,     0,     0,
       0,     0,     0,     0,    33,     0,    25,    29,    28,    26,
       0,     0,    73,    64,     0,     0,     0,     0,     0,     0,
      78,    36,     0,     0,     0,     0,     0,     0,    63,     0,
       0,     0,     0,    58,     0,     0,     0,     0,     0,    74,
       0,    75,    60,     0,     0,    80,     0,     0,     0,    59,
      57,     0,     0,     0,    76,     0,     0,     0,    77,     0,
      27,    65,     0,    82,    84,     0,     0,    55,     0,     0,
       0,    35,    56,    54
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,     3,     4,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,    35,     5,    10,    68,   131,   162,
     232,    48,    49,    50,    51,   276,    52,   229,    53,   154,
     237,    54,    55,    56,    57,    58,    59,   221,   238,   243,
      60,    61,    62,   186,    63,   187,    64,   188,    65,    11,
      66,   167,   244,   118,   135,   136,   137,   138
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -230
static const yytype_int16 yypact[] =
{
     -25,   -26,   -21,    39,  -230,  -230,    34,    74,  -230,  -230,
      24,    -5,  -230,    -8,    43,    35,    41,  -230,    -7,    58,
     -14,    44,    45,   -11,    74,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,   201,    12,   201,    53,
    -230,    55,   201,    52,    75,  -230,  -230,  -230,    24,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,   -30,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,  -230,    48,    57,  -230,
     -24,    26,    33,    36,    38,    40,    42,   201,   201,    87,
      89,   201,   201,  -230,  -230,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,  -230,    47,  -230,  -230,
      49,    77,   201,    50,   201,   201,  -230,  -230,  -230,    61,
      66,    78,  -230,  -230,  -230,    56,   -17,  -230,  -230,    60,
     -24,   -24,   -24,   -24,   -24,    59,    51,    63,    64,    83,
      67,   201,   201,  -230,   201,    68,     4,    69,    70,    86,
      73,   201,  -230,  -230,  -230,  -230,  -230,    76,    81,    82,
      85,    91,    92,  -230,   201,   -24,   -24,   201,   201,    94,
      71,    84,   201,  -230,  -230,  -230,    72,    95,    96,   201,
     201,    97,  -230,    99,  -230,  -230,  -230,  -230,  -230,  -230,
     102,   103,   104,   105,   106,  -230,   201,   201,   107,    60,
      60,   -24,   100,   108,  -230,   110,  -230,  -230,  -230,  -230,
     201,   -13,  -230,   119,   201,   109,   111,   112,   201,   -37,
    -230,  -230,   114,   116,   201,   124,   201,   120,   128,     0,
     121,   -24,   -24,  -230,   118,   201,    -6,   -24,   201,  -230,
     201,  -230,  -230,   201,   122,  -230,   117,   123,   -24,  -230,
    -230,   125,   127,   131,  -230,   129,   133,   134,  -230,   -24,
    -230,  -230,   -24,  -230,  -230,   130,     2,  -230,   136,   -24,
     137,  -230,  -230,  -230
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -230,  -230,  -230,  -230,   145,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,   135,  -230,  -230,  -230,  -230,  -230,  -230,  -230,
    -230,  -230,  -230,  -230,   126,   140,  -230,   -43,   -32,  -229,
    -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,  -230,
      -1,  -153,   -36,  -230,  -121,  -230,    65,    93
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const yytype_uint16 yytable[] =
{
     117,   253,   120,   132,     9,    12,   123,   251,    74,   236,
      69,    75,    77,     1,     2,    81,   259,    45,    46,   168,
     169,   170,   171,   172,   264,   245,    78,   133,   134,    82,
      36,    67,     6,     9,   133,   134,    37,     7,    38,     8,
      39,   145,   146,     9,    40,   149,   150,    41,    71,   234,
     235,    70,   260,    72,   201,   202,   225,   226,    42,   183,
     184,   185,   234,   254,   279,   280,    73,    43,    44,    76,
     119,    45,    46,    47,   121,    79,    80,    13,    14,   122,
     124,   125,    15,   129,    16,   139,   155,    17,   157,   158,
     227,    18,   140,    19,   130,   141,    20,   142,   147,   143,
     148,   144,   159,    21,    22,   153,    23,   151,   160,   152,
     156,   174,   161,   166,   163,   179,   180,   173,   181,   191,
     256,   257,   175,   176,   177,   193,   261,   178,   182,   189,
     190,   192,   206,   209,   194,   253,   228,   268,   200,   195,
     196,   203,   204,   197,   207,   250,   208,   220,   275,   198,
     199,   277,   205,   212,   213,   214,   210,   211,   282,   215,
     216,   217,   218,   219,   231,   236,   230,   265,   224,    83,
     222,   223,   240,   241,   242,   247,   248,   258,   252,   255,
     266,   239,   127,   126,   233,   270,   267,   269,   222,   271,
     272,   273,   274,   278,   281,   283,   128,   246,   249,     0,
       0,   164,     0,     0,    84,    85,    86,     0,     0,    87,
       0,    88,   262,    89,   263,    90,    91,    92,    93,    94,
      95,     0,     0,    96,    97,     0,    98,    99,     0,   165,
     100,   101,   102,   103,     0,     0,     0,   104,   105,   106,
     107,     0,     0,   108,   109,   110,   111,     0,     0,     0,
       0,   112,     0,     0,     0,   113,   114,   115,   116
};

static const yytype_int16 yycheck[] =
{
      36,     7,    38,    27,     9,     6,    42,   236,    15,    46,
      11,    18,    26,    38,    39,    26,   245,    47,    48,   140,
     141,   142,   143,   144,   253,    62,    40,    51,    52,    40,
       6,    36,    58,     9,    51,    52,    12,    58,    14,     0,
      16,    77,    78,     9,    20,    81,    82,    23,     5,    62,
      63,    59,    58,    18,   175,   176,   209,   210,    34,    55,
      56,    57,    62,    63,    62,    63,    25,    43,    44,    11,
      58,    47,    48,    49,    21,    31,    31,     3,     4,    24,
      28,     6,     8,    35,    10,    59,   122,    13,   124,   125,
     211,    17,    59,    19,    37,    59,    22,    59,    11,    59,
      11,    59,    41,    29,    30,    28,    32,    60,    42,    60,
      60,    60,    34,    53,    58,   151,   152,    58,   154,    33,
     241,   242,    59,    59,    41,   161,   247,    60,    60,    60,
      60,    58,    61,    61,    58,     7,    36,   258,   174,    58,
      58,   177,   178,    58,    60,    21,   182,    41,   269,    58,
      58,   272,    58,   189,   190,    58,    61,    61,   279,    60,
      58,    58,    58,    58,    54,    46,    58,    45,    61,    24,
     206,   207,    63,    62,    62,    61,    60,    59,    58,    58,
      63,   224,    56,    48,   220,    58,    63,    62,   224,    58,
      61,    58,    58,    63,    58,    58,    56,   229,   234,    -1,
      -1,   136,    -1,    -1,     3,     4,     5,    -1,    -1,     8,
      -1,    10,   248,    12,   250,    14,    15,    16,    17,    18,
      19,    -1,    -1,    22,    23,    -1,    25,    26,    -1,   136,
      29,    30,    31,    32,    -1,    -1,    -1,    36,    37,    38,
      39,    -1,    -1,    42,    43,    44,    45,    -1,    -1,    -1,
      -1,    50,    -1,    -1,    -1,    54,    55,    56,    57
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    38,    39,    65,    66,    79,    58,    58,     0,     9,
      80,   113,   114,     3,     4,     8,    10,    13,    17,    19,
      22,    29,    30,    32,    67,    68,    69,    70,    71,    72,
      73,    74,    75,    76,    77,    78,     6,    12,    14,    16,
      20,    23,    34,    43,    44,    47,    48,    49,    85,    86,
      87,    88,    90,    92,    95,    96,    97,    98,    99,   100,
     104,   105,   106,   108,   110,   112,   114,    36,    81,   114,
      59,     5,    18,    25,    15,    18,    11,    26,    40,    31,
      31,    26,    40,    68,     3,     4,     5,     8,    10,    12,
      14,    15,    16,    17,    18,    19,    22,    23,    25,    26,
      29,    30,    31,    32,    36,    37,    38,    39,    42,    43,
      44,    45,    50,    54,    55,    56,    57,   116,   117,    58,
     116,    21,    24,   116,    28,     6,    86,    98,    99,    35,
      37,    82,    27,    51,    52,   118,   119,   120,   121,    59,
      59,    59,    59,    59,    59,   116,   116,    11,    11,   116,
     116,    60,    60,    28,    93,   116,    60,   116,   116,    41,
      42,    34,    83,    58,   120,   121,    53,   115,   118,   118,
     118,   118,   118,    58,    60,    59,    59,    41,    60,   116,
     116,   116,    60,    55,    56,    57,   107,   109,   111,    60,
      60,    33,    58,   116,    58,    58,    58,    58,    58,    58,
     116,   118,   118,   116,   116,    58,    61,    60,   116,    61,
      61,    61,   116,   116,    58,    60,    58,    58,    58,    58,
      41,   101,   116,   116,    61,   115,   115,   118,    36,    91,
      58,    54,    84,   116,    62,    63,    46,    94,   102,   101,
      63,    62,    62,   103,   116,    62,   102,    61,    60,   116,
      21,   103,    58,     7,    63,    58,   118,   118,    59,   103,
      58,   118,   116,   116,   103,    45,    63,    63,   118,    62,
      58,    58,    61,    58,    58,   118,    89,   118,    63,    62,
      63,    58,   118,    58
};

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK (1);						\
      goto yybackup;						\
    }								\
  else								\
    {								\
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (YYID (0))


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (YYID (N))                                                    \
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (YYID (0))
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
	      (Loc).first_line, (Loc).first_column,	\
	      (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (YYID (0))

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)			  \
do {									  \
  if (yydebug)								  \
    {									  \
      YYFPRINTF (stderr, "%s ", Title);					  \
      yy_symbol_print (stderr,						  \
		  Type, Value); \
      YYFPRINTF (stderr, "\n");						  \
    }									  \
} while (YYID (0))


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_value_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# else
  YYUSE (yyoutput);
# endif
  switch (yytype)
    {
      default:
	break;
    }
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
#else
static void
yy_symbol_print (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE const * const yyvaluep;
#endif
{
  if (yytype < YYNTOKENS)
    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
#else
static void
yy_stack_print (yybottom, yytop)
    yytype_int16 *yybottom;
    yytype_int16 *yytop;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (YYID (0))


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
#else
static void
yy_reduce_print (yyvsp, yyrule)
    YYSTYPE *yyvsp;
    int yyrule;
#endif
{
  int yynrhs = yyr2[yyrule];
  int yyi;
  unsigned long int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
	     yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
		       &(yyvsp[(yyi + 1) - (yynrhs)])
		       		       );
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (yyvsp, Rule); \
} while (YYID (0))

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static YYSIZE_T
yystrlen (const char *yystr)
#else
static YYSIZE_T
yystrlen (yystr)
    const char *yystr;
#endif
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static char *
yystpcpy (char *yydest, const char *yysrc)
#else
static char *
yystpcpy (yydest, yysrc)
    char *yydest;
    const char *yysrc;
#endif
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
	switch (*++yyp)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++yyp != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (yyres)
	      yyres[yyn] = *yyp;
	    yyn++;
	    break;

	  case '"':
	    if (yyres)
	      yyres[yyn] = '\0';
	    return yyn;
	  }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into YYRESULT an error message about the unexpected token
   YYCHAR while in state YYSTATE.  Return the number of bytes copied,
   including the terminating null byte.  If YYRESULT is null, do not
   copy anything; just return the number of bytes that would be
   copied.  As a special case, return 0 if an ordinary "syntax error"
   message will do.  Return YYSIZE_MAXIMUM if overflow occurs during
   size calculation.  */
static YYSIZE_T
yysyntax_error (char *yyresult, int yystate, int yychar)
{
  int yyn = yypact[yystate];

  if (! (YYPACT_NINF < yyn && yyn <= YYLAST))
    return 0;
  else
    {
      int yytype = YYTRANSLATE (yychar);
      YYSIZE_T yysize0 = yytnamerr (0, yytname[yytype]);
      YYSIZE_T yysize = yysize0;
      YYSIZE_T yysize1;
      int yysize_overflow = 0;
      enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
      char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
      int yyx;

# if 0
      /* This is so xgettext sees the translatable formats that are
	 constructed on the fly.  */
      YY_("syntax error, unexpected %s");
      YY_("syntax error, unexpected %s, expecting %s");
      YY_("syntax error, unexpected %s, expecting %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s");
      YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
# endif
      char *yyfmt;
      char const *yyf;
      static char const yyunexpected[] = "syntax error, unexpected %s";
      static char const yyexpecting[] = ", expecting %s";
      static char const yyor[] = " or %s";
      char yyformat[sizeof yyunexpected
		    + sizeof yyexpecting - 1
		    + ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
		       * (sizeof yyor - 1))];
      char const *yyprefix = yyexpecting;

      /* Start YYX at -YYN if negative to avoid negative indexes in
	 YYCHECK.  */
      int yyxbegin = yyn < 0 ? -yyn : 0;

      /* Stay within bounds of both yycheck and yytname.  */
      int yychecklim = YYLAST - yyn + 1;
      int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
      int yycount = 1;

      yyarg[0] = yytname[yytype];
      yyfmt = yystpcpy (yyformat, yyunexpected);

      for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	  {
	    if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
	      {
		yycount = 1;
		yysize = yysize0;
		yyformat[sizeof yyunexpected - 1] = '\0';
		break;
	      }
	    yyarg[yycount++] = yytname[yyx];
	    yysize1 = yysize + yytnamerr (0, yytname[yyx]);
	    yysize_overflow |= (yysize1 < yysize);
	    yysize = yysize1;
	    yyfmt = yystpcpy (yyfmt, yyprefix);
	    yyprefix = yyor;
	  }

      yyf = YY_(yyformat);
      yysize1 = yysize + yystrlen (yyf);
      yysize_overflow |= (yysize1 < yysize);
      yysize = yysize1;

      if (yysize_overflow)
	return YYSIZE_MAXIMUM;

      if (yyresult)
	{
	  /* Avoid sprintf, as that infringes on the user's name space.
	     Don't have undefined behavior even if the translation
	     produced a string with the wrong number of "%s"s.  */
	  char *yyp = yyresult;
	  int yyi = 0;
	  while ((*yyp = *yyf) != '\0')
	    {
	      if (*yyp == '%' && yyf[1] == 's' && yyi < yycount)
		{
		  yyp += yytnamerr (yyp, yyarg[yyi++]);
		  yyf += 2;
		}
	      else
		{
		  yyp++;
		  yyf++;
		}
	    }
	}
      return yysize;
    }
}
#endif /* YYERROR_VERBOSE */


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

/*ARGSUSED*/
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yymsg, yytype, yyvaluep)
    const char *yymsg;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  YYUSE (yyvaluep);

  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  switch (yytype)
    {

      default:
	break;
    }
}

/* Prevent warnings from -Wmissing-prototypes.  */
#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int yyparse (void *YYPARSE_PARAM);
#else
int yyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */


/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*-------------------------.
| yyparse or yypush_parse.  |
`-------------------------*/

#ifdef YYPARSE_PARAM
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void *YYPARSE_PARAM)
#else
int
yyparse (YYPARSE_PARAM)
    void *YYPARSE_PARAM;
#endif
#else /* ! YYPARSE_PARAM */
#if (defined __STDC__ || defined __C99__FUNC__ \
     || defined __cplusplus || defined _MSC_VER)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{


    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       `yyss': related to states.
       `yyvs': related to semantic values.

       Refer to the stacks thru separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yytoken = 0;
  yyss = yyssa;
  yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */
  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack.  Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	yytype_int16 *yyss1 = yyss;

	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow (YY_("memory exhausted"),
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),
		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	yytype_int16 *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyexhaustedlab;
	YYSTACK_RELOCATE (yyss_alloc, yyss);
	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  *++yyvsp = yylval;

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 18:

/* Line 1455 of yacc.c  */
#line 162 "parser.y"
    {
						if (archive_dir != NULL)
							parse_error("duplicate archive dir specification");
						else
							archive_dir = strdup((yyvsp[(4) - (5)].str));
					}
    break;

  case 19:

/* Line 1455 of yacc.c  */
#line 171 "parser.y"
    {
						if (destination_dir != NULL)
							parse_error("duplicate destination dir specification");
						else
							destination_dir = strdup((yyvsp[(4) - (5)].str));
					}
    break;

  case 20:

/* Line 1455 of yacc.c  */
#line 180 "parser.y"
    {
						if (destination_conninfo != NULL)
							parse_error("duplicate destination database specification");
						else
							destination_conninfo = strdup((yyvsp[(4) - (5)].str));
					}
    break;

  case 21:

/* Line 1455 of yacc.c  */
#line 189 "parser.y"
    {
						if (logfile_path != NULL)
							parse_error("duplicate logfile path specification");
						else
							logfile_path = strdup((yyvsp[(3) - (4)].str));
					}
    break;

  case 22:

/* Line 1455 of yacc.c  */
#line 198 "parser.y"
    {
						max_archives = (yyvsp[(4) - (5)].ival);
					}
    break;

  case 23:

/* Line 1455 of yacc.c  */
#line 204 "parser.y"
    {
						if (cluster_name != NULL)
							parse_error("duplicate cluster name specification");
						else
							cluster_name = strdup((yyvsp[(4) - (5)].str));
					}
    break;

  case 24:

/* Line 1455 of yacc.c  */
#line 213 "parser.y"
    {
						RenameObject *new;

						new = (RenameObject *)malloc(sizeof(RenameObject));
						memset(new, 0, sizeof(RenameObject));

						new->old_namespace = (yyvsp[(3) - (4)].str);

						config_add_rename(new);
					}
    break;

  case 25:

/* Line 1455 of yacc.c  */
#line 224 "parser.y"
    {
						RenameObject *new;

						new = (RenameObject *)malloc(sizeof(RenameObject));
						memset(new, 0, sizeof(RenameObject));

						new->old_namespace = (yyvsp[(3) - (6)].str);
						new->old_name      = (yyvsp[(5) - (6)].str);

						config_add_rename(new);
					}
    break;

  case 26:

/* Line 1455 of yacc.c  */
#line 236 "parser.y"
    {
						RenameObject *new;

						new = (RenameObject *)malloc(sizeof(RenameObject));
						memset(new, 0, sizeof(RenameObject));

						new->old_namespace = (yyvsp[(3) - (6)].str);
						new->new_namespace = (yyvsp[(5) - (6)].str);

						config_add_rename(new);
					}
    break;

  case 27:

/* Line 1455 of yacc.c  */
#line 248 "parser.y"
    {
						RenameObject *new;

						new = (RenameObject *)malloc(sizeof(RenameObject));
						memset(new, 0, sizeof(RenameObject));

						new->old_namespace = (yyvsp[(3) - (10)].str);
						new->old_name      = (yyvsp[(5) - (10)].str);
						new->new_namespace = (yyvsp[(7) - (10)].str);
						new->new_name      = (yyvsp[(9) - (10)].str);

						config_add_rename(new);
					}
    break;

  case 28:

/* Line 1455 of yacc.c  */
#line 264 "parser.y"
    {
						ProcessingCommand	  **pptr;

						pptr = &pre_processing_commands;
						while (*pptr != NULL)
							pptr = &((*pptr)->next);
						
						*pptr = (ProcessingCommand *)malloc(sizeof(ProcessingCommand));
						(*pptr)->command = (yyvsp[(5) - (6)].str);
						(*pptr)->next = NULL;
					}
    break;

  case 29:

/* Line 1455 of yacc.c  */
#line 278 "parser.y"
    {
						ProcessingCommand	  **pptr;

						pptr = &post_processing_commands;
						while (*pptr != NULL)
							pptr = &((*pptr)->next);
						
						*pptr = (ProcessingCommand *)malloc(sizeof(ProcessingCommand));
						(*pptr)->command = (yyvsp[(5) - (6)].str);
						(*pptr)->next = NULL;
					}
    break;

  case 30:

/* Line 1455 of yacc.c  */
#line 292 "parser.y"
    {
						ProcessingCommand	  **pptr;

						pptr = &error_commands;
						while (*pptr != NULL)
							pptr = &((*pptr)->next);
						
						*pptr = (ProcessingCommand *)malloc(sizeof(ProcessingCommand));
						(*pptr)->command = (yyvsp[(4) - (5)].str);
						(*pptr)->next = NULL;
					}
    break;

  case 33:

/* Line 1455 of yacc.c  */
#line 323 "parser.y"
    {
						if (process_simple_sql(
							"set session_replication_role to replica;") < 0)
							YYABORT;
					}
    break;

  case 34:

/* Line 1455 of yacc.c  */
#line 331 "parser.y"
    {
						if (process_start_transaction("start transaction;") < 0)
							YYABORT;
					}
    break;

  case 35:

/* Line 1455 of yacc.c  */
#line 338 "parser.y"
    {
						SlonDString	ds;
						int			rc;

						dstring_init(&ds);
						slon_mkquery(&ds, "select %s.%s('%s', '%s');",
								(yyvsp[(2) - (10)].str), (yyvsp[(4) - (10)].str), (yyvsp[(6) - (10)].str), (yyvsp[(8) - (10)].str));
						rc = process_check_at_counter((yyvsp[(6) - (10)].str));
						free((yyvsp[(2) - (10)].str));
						free((yyvsp[(4) - (10)].str));
						free((yyvsp[(6) - (10)].str));
						free((yyvsp[(8) - (10)].str));

						if (rc < 0)
						{
							dstring_free(&ds);
							YYABORT;
						}
						if (rc == 1)
						{
							dstring_free(&ds);
							YYACCEPT;
						}
						
						if (process_simple_sql(dstring_data(&ds)) < 0)
						{
							dstring_free(&ds);
							YYABORT;
						}
						else
							dstring_free(&ds);
					}
    break;

  case 36:

/* Line 1455 of yacc.c  */
#line 372 "parser.y"
    {
						char   *ret;
						size_t toklen=yyget_leng();
						ret = malloc(toklen + 1);
						memcpy(ret, yytext, toklen);
						ret[toklen] = '\0';

						(yyval.str) = ret;
					}
    break;

  case 53:

/* Line 1455 of yacc.c  */
#line 404 "parser.y"
    {
						if (process_end_transaction("commit;") < 0)
							YYABORT;
					}
    break;

  case 54:

/* Line 1455 of yacc.c  */
#line 411 "parser.y"
    {
						InsertStmt	stmt;
						AttElem	   *nelem;
						AttElem	   *velem;
						AttElem	   *next;
						int			rc;

						stmt.namespace	= (yyvsp[(3) - (13)].str);
						stmt.tablename	= (yyvsp[(5) - (13)].str);
						stmt.attributes	= (yyvsp[(7) - (13)].att_elem_list);

						for (nelem = (yyvsp[(7) - (13)].att_elem_list)->list_head, velem = (yyvsp[(11) - (13)].att_elem_list)->list_head;
								nelem != NULL && velem != NULL;
								nelem = nelem->next, velem = next)
						{
							nelem->attvalue = velem->attvalue;
							next = velem->next;
							free(velem);
						}
						free((yyvsp[(11) - (13)].att_elem_list));

						rc = process_insert(&stmt);

						for (nelem = (yyvsp[(7) - (13)].att_elem_list)->list_head; nelem != NULL; nelem = next)
						{
							next = nelem->next;
							free(nelem->attname);
							if (nelem->attvalue != NULL)
								free(nelem->attvalue);
							free(nelem);
						}
						free(stmt.namespace);
						free(stmt.tablename);
						free(stmt.attributes);

						if (rc < 0)
							YYABORT;
					}
    break;

  case 55:

/* Line 1455 of yacc.c  */
#line 452 "parser.y"
    {
						AttElemList	   *new;
						new = (AttElemList *)malloc(sizeof(AttElemList));

						new->list_head = (AttElem *)malloc(sizeof(AttElem));
						new->list_tail = new->list_head;

						new->list_head->attname = NULL;
						new->list_head->attvalue = (yyvsp[(1) - (1)].str);
						new->list_head->next = NULL;

						(yyval.att_elem_list) = new;
					}
    break;

  case 56:

/* Line 1455 of yacc.c  */
#line 466 "parser.y"
    {
						AttElem		   *new;
						new = (AttElem *)malloc(sizeof(AttElem));

						new->attname = NULL;
						new->attvalue = (yyvsp[(3) - (3)].str);
						new->next = NULL;

						(yyvsp[(1) - (3)].att_elem_list)->list_tail->next = new;
						(yyvsp[(1) - (3)].att_elem_list)->list_tail = new;

						(yyval.att_elem_list) = (yyvsp[(1) - (3)].att_elem_list);
					}
    break;

  case 57:

/* Line 1455 of yacc.c  */
#line 482 "parser.y"
    {
						UpdateStmt		stmt;
						AttElem		   *elem;
						AttElem		   *next;
						int				rc;

						stmt.namespace		= (yyvsp[(3) - (8)].str);
						stmt.tablename		= (yyvsp[(5) - (8)].str);
						stmt.changes		= (yyvsp[(6) - (8)].att_elem_list);
						stmt.qualification	= (yyvsp[(7) - (8)].att_elem_list);

						rc = process_update(&stmt);

						for (elem = stmt.changes->list_head; elem != NULL; elem = next)
						{
							next = elem->next;
							free(elem->attname);
							if (elem->attvalue != NULL)
								free(elem->attvalue);
							free(elem);
						}
						free(stmt.changes);
						for (elem = stmt.qualification->list_head; elem != NULL; elem = next)
						{
							next = elem->next;
							free(elem->attname);
							if (elem->attvalue != NULL)
								free(elem->attvalue);
							free(elem);
						}
						free(stmt.namespace);
						free(stmt.tablename);
						free(stmt.qualification);

						if (rc < 0)
							YYABORT;
					}
    break;

  case 58:

/* Line 1455 of yacc.c  */
#line 522 "parser.y"
    {
						AttElemList	   *new;
						new = (AttElemList *)malloc(sizeof(AttElemList));

						new->list_head = (yyvsp[(2) - (2)].att_elem);
						new->list_tail = (yyvsp[(2) - (2)].att_elem);

						(yyval.att_elem_list) = new;
					}
    break;

  case 59:

/* Line 1455 of yacc.c  */
#line 532 "parser.y"
    { 
						(yyvsp[(1) - (3)].att_elem_list)->list_tail->next = (yyvsp[(3) - (3)].att_elem);
						(yyvsp[(1) - (3)].att_elem_list)->list_tail = (yyvsp[(3) - (3)].att_elem);

						(yyval.att_elem_list) = (yyvsp[(1) - (3)].att_elem_list);
					}
    break;

  case 60:

/* Line 1455 of yacc.c  */
#line 540 "parser.y"
    {
						DeleteStmt		stmt;
						AttElem		   *elem;
						AttElem		   *next;
						int				rc;

						stmt.namespace		= (yyvsp[(4) - (8)].str);
						stmt.tablename		= (yyvsp[(6) - (8)].str);
						stmt.only			= (yyvsp[(3) - (8)].ival);
						stmt.qualification	= (yyvsp[(7) - (8)].att_elem_list);

						rc = process_delete(&stmt);

						if (stmt.qualification != NULL)
						{
							for (elem = stmt.qualification->list_head; elem != NULL; elem = next)
							{
								next = elem->next;
								free(elem->attname);
								if (elem->attvalue != NULL)
									free(elem->attvalue);
								free(elem);
							}
							free(stmt.qualification);
						}
						free(stmt.namespace);
						free(stmt.tablename);

						if (rc < 0)
							YYABORT;
					}
    break;

  case 61:

/* Line 1455 of yacc.c  */
#line 574 "parser.y"
    {
						(yyval.ival) = 1;
					}
    break;

  case 62:

/* Line 1455 of yacc.c  */
#line 578 "parser.y"
    {
						(yyval.ival) = 0;
					}
    break;

  case 63:

/* Line 1455 of yacc.c  */
#line 584 "parser.y"
    {
						(yyval.att_elem_list) = (yyvsp[(1) - (1)].att_elem_list);
					}
    break;

  case 64:

/* Line 1455 of yacc.c  */
#line 588 "parser.y"
    {
						(yyval.att_elem_list) = NULL;
					}
    break;

  case 65:

/* Line 1455 of yacc.c  */
#line 594 "parser.y"
    {
						CopyStmt		stmt;
						AttElem		   *elem;
						AttElem		   *next;
						int				rc;

						stmt.namespace		= (yyvsp[(2) - (10)].str);
						stmt.tablename		= (yyvsp[(4) - (10)].str);
						stmt.attributes		= (yyvsp[(6) - (10)].att_elem_list);
						stmt.from			= (yyvsp[(9) - (10)].str);

						rc = process_copy(&stmt);

						for (elem = stmt.attributes->list_head; elem != NULL; elem = next)
						{
							next = elem->next;
							free(elem->attname);
							if (elem->attvalue != NULL)
								free(elem->attvalue);
							free(elem);
						}
						free(stmt.attributes);
						free(stmt.namespace);
						free(stmt.tablename);

						if (rc < 0)
							YYABORT;
					}
    break;

  case 66:

/* Line 1455 of yacc.c  */
#line 625 "parser.y"
    {
						int rc;

						rc = process_copydata((yyvsp[(1) - (1)].str));
						free((yyvsp[(1) - (1)].str));

						if (rc < 0)
							YYABORT;
					}
    break;

  case 67:

/* Line 1455 of yacc.c  */
#line 635 "parser.y"
    {
						int rc;

						dstring_append((yyvsp[(1) - (2)].dstring), (yyvsp[(2) - (2)].str));
						dstring_terminate((yyvsp[(1) - (2)].dstring));
						free((yyvsp[(2) - (2)].str));
						rc = process_copydata(dstring_data((yyvsp[(1) - (2)].dstring)));
						dstring_free((yyvsp[(1) - (2)].dstring));

						if (rc < 0)
							YYABORT;
					}
    break;

  case 68:

/* Line 1455 of yacc.c  */
#line 650 "parser.y"
    {
						SlonDString	*new;

						new = (SlonDString *)malloc(sizeof(SlonDString));
						dstring_init(new);
						dstring_append(new, (yyvsp[(1) - (1)].str));
						free((yyvsp[(1) - (1)].str));

						(yyval.dstring) = new;
					}
    break;

  case 69:

/* Line 1455 of yacc.c  */
#line 661 "parser.y"
    {
						dstring_append((yyvsp[(1) - (2)].dstring), (yyvsp[(2) - (2)].str));
						free((yyvsp[(2) - (2)].str));

						(yyval.dstring) = (yyvsp[(1) - (2)].dstring);
					}
    break;

  case 70:

/* Line 1455 of yacc.c  */
#line 670 "parser.y"
    {
						(yyval.str) = strdup(yychunk);
					}
    break;

  case 71:

/* Line 1455 of yacc.c  */
#line 676 "parser.y"
    {
						(yyval.str) = strdup(yychunk);
					}
    break;

  case 72:

/* Line 1455 of yacc.c  */
#line 682 "parser.y"
    {
						if (process_copyend() < 0)
							YYABORT;
					}
    break;

  case 73:

/* Line 1455 of yacc.c  */
#line 689 "parser.y"
    {
						AttElemList	   *new;
						new = (AttElemList *)malloc(sizeof(AttElemList));

						new->list_head = (AttElem *)malloc(sizeof(AttElem));
						new->list_tail = new->list_head;

						new->list_head->attname = (yyvsp[(1) - (1)].str);
						new->list_head->attvalue = NULL;
						new->list_head->next = NULL;

						(yyval.att_elem_list) = new;
					}
    break;

  case 74:

/* Line 1455 of yacc.c  */
#line 703 "parser.y"
    {
						AttElem		   *new;
						new = (AttElem *)malloc(sizeof(AttElem));

						new->attname = (yyvsp[(3) - (3)].str);
						new->attvalue = NULL;
						new->next = NULL;

						(yyvsp[(1) - (3)].att_elem_list)->list_tail->next = new;
						(yyvsp[(1) - (3)].att_elem_list)->list_tail = new;

						(yyval.att_elem_list) = (yyvsp[(1) - (3)].att_elem_list);
					}
    break;

  case 75:

/* Line 1455 of yacc.c  */
#line 719 "parser.y"
    {
						AttElemList	   *new;
						new = (AttElemList *)malloc(sizeof(AttElemList));

						new->list_head = (yyvsp[(2) - (2)].att_elem);
						new->list_tail = (yyvsp[(2) - (2)].att_elem);

						(yyval.att_elem_list) = new;
					}
    break;

  case 76:

/* Line 1455 of yacc.c  */
#line 729 "parser.y"
    {
						(yyvsp[(1) - (3)].att_elem_list)->list_tail->next = (yyvsp[(3) - (3)].att_elem);
						(yyvsp[(1) - (3)].att_elem_list)->list_tail = (yyvsp[(3) - (3)].att_elem);

						(yyval.att_elem_list) = (yyvsp[(1) - (3)].att_elem_list);
					}
    break;

  case 77:

/* Line 1455 of yacc.c  */
#line 738 "parser.y"
    {
						AttElem	   *new = (AttElem *)malloc(sizeof(AttElem));

						new->attname = (yyvsp[(1) - (3)].str);
						new->attvalue = (yyvsp[(3) - (3)].str);
						new->next = NULL;

						(yyval.att_elem) = new;
					}
    break;

  case 78:

/* Line 1455 of yacc.c  */
#line 750 "parser.y"
    {
						SlonDString	ds;
						char	   *namespace;
						char	   *tablename;

						if (lookup_rename((yyvsp[(3) - (6)].str), (yyvsp[(5) - (6)].str), &namespace, &tablename) == 1)
						{
							dstring_init(&ds);
							slon_mkquery(&ds, "vacuum analyze %s.%s;",
									(yyvsp[(3) - (6)].str), (yyvsp[(5) - (6)].str));
							free((yyvsp[(3) - (6)].str));
							free((yyvsp[(5) - (6)].str));
							if (process_simple_sql(dstring_data(&ds)) < 0)
							{
								dstring_free(&ds);
								YYABORT;
							}
							else
								dstring_free(&ds);
						}
						else
						{
							free((yyvsp[(3) - (6)].str));
							free((yyvsp[(5) - (6)].str));
						}
					}
    break;

  case 79:

/* Line 1455 of yacc.c  */
#line 779 "parser.y"
    {
						SlonDString	ds;
						char	   *namespace;
						char	   *tablename;

						if (lookup_rename((yyvsp[(2) - (5)].str), (yyvsp[(4) - (5)].str), &namespace, &tablename) == 1)
						{
							dstring_init(&ds);
							slon_mkquery(&ds, "analyze %s.%s;",
									namespace, tablename);
							free((yyvsp[(2) - (5)].str));
							free((yyvsp[(4) - (5)].str));
							if (process_simple_sql(dstring_data(&ds)) < 0)
							{
								dstring_free(&ds);
								YYABORT;
							}
							else
								dstring_free(&ds);
						}
						else
						{
							free((yyvsp[(2) - (5)].str));
							free((yyvsp[(4) - (5)].str));
						}
					}
    break;

  case 80:

/* Line 1455 of yacc.c  */
#line 808 "parser.y"
    {
						SlonDString	ds;
						dstring_init(&ds);
						slon_mkquery(&ds, "select %s.%s(%d);",
								(yyvsp[(2) - (8)].str), (yyvsp[(4) - (8)].str), (yyvsp[(6) - (8)].ival));
						free((yyvsp[(2) - (8)].str));
						free((yyvsp[(4) - (8)].str));
						if (process_simple_sql(dstring_data(&ds)) < 0)
						{
							dstring_free(&ds);
							YYABORT;
						}
						else
							dstring_free(&ds);
					}
    break;

  case 81:

/* Line 1455 of yacc.c  */
#line 825 "parser.y"
    {
						char   *ret;
						size_t toklen = yyget_leng();
						ret = malloc(toklen + 1);
						memcpy(ret, yytext, toklen);
						ret[toklen] = '\0';

						(yyval.str) = ret;
					}
    break;

  case 82:

/* Line 1455 of yacc.c  */
#line 837 "parser.y"
    {
						SlonDString	ds;
						dstring_init(&ds);
						slon_mkquery(&ds, "select %s.%s(%d, '%s');",
								(yyvsp[(2) - (10)].str), (yyvsp[(4) - (10)].str), (yyvsp[(6) - (10)].ival), (yyvsp[(8) - (10)].str));
						free((yyvsp[(2) - (10)].str));
						free((yyvsp[(4) - (10)].str));
						free((yyvsp[(8) - (10)].str));
						if (process_simple_sql(dstring_data(&ds)) < 0)
						{
							dstring_free(&ds);
							YYABORT;
						}
						else
							dstring_free(&ds);
					}
    break;

  case 83:

/* Line 1455 of yacc.c  */
#line 855 "parser.y"
    {
						char   *ret;
						size_t toklen= yyget_leng();
						ret = malloc(toklen + 1);
						memcpy(ret, yytext, toklen);
						ret[toklen] = '\0';

						(yyval.str) = ret;
					}
    break;

  case 84:

/* Line 1455 of yacc.c  */
#line 867 "parser.y"
    {
						SlonDString	ds;
						dstring_init(&ds);
						slon_mkquery(&ds, "select %s.%s('%s', '%s');",
								(yyvsp[(2) - (10)].str), (yyvsp[(4) - (10)].str), (yyvsp[(6) - (10)].str), (yyvsp[(8) - (10)].str));
						free((yyvsp[(2) - (10)].str));
						free((yyvsp[(4) - (10)].str));
						free((yyvsp[(6) - (10)].str));
						free((yyvsp[(8) - (10)].str));
						if (process_simple_sql(dstring_data(&ds)) < 0)
						{
							dstring_free(&ds);
							YYABORT;
						}
						else
							dstring_free(&ds);
					}
    break;

  case 85:

/* Line 1455 of yacc.c  */
#line 886 "parser.y"
    {
						char   *ret;
						size_t toklen = yyget_leng();
						ret = malloc(toklen + 1);
						memcpy(ret, yytext, toklen);
						ret[toklen] = '\0';

						(yyval.str) = ret;
					}
    break;

  case 86:

/* Line 1455 of yacc.c  */
#line 898 "parser.y"
    {
						SlonDString	ds;
						int			c;
						int			nstmts;
						int			i;

						if (process_simple_sql("-- DDL_SCRIPT") < 0)
							YYABORT;

						dstring_init(&ds);
						while ((c = scan_yyinput()) != EOF)
						{
							dstring_addchar(&ds, c);
						}
						dstring_terminate(&ds);

						if ((nstmts = scan_for_statements(dstring_data(&ds))) < 0)
						{
							errlog(LOG_ERROR, "scan_for_statements failed\n");
							dstring_free(&ds);
							YYABORT;
						}

						for (i = 0; i < nstmts; i++)
						{
							int start = (i == 0) ? 0 : STMTS[i - 1] + 1;
							int end = STMTS[i];

							dstring_data(&ds)[end] = '\0';

							if (process_simple_sql(dstring_data(&ds) + start) < 0)
							{
								dstring_free(&ds);
								YYABORT;
							}
						}
						dstring_free(&ds);

						/*
						 * Just in case
						 */
						process_end_transaction("rollback;");

						YYACCEPT;
					}
    break;

  case 89:

/* Line 1455 of yacc.c  */
#line 950 "parser.y"
    {
						char   *str;
						size_t toklen = yyget_leng();
						str = malloc(toklen + 1);
						memcpy(str, yytext, toklen);
						str[toklen] = '\0';

						if (process_simple_sql(str) < 0)
						{
							free(str);
							YYABORT;
						}
						else
							free(str);
					}
    break;

  case 90:

/* Line 1455 of yacc.c  */
#line 968 "parser.y"
    {
						(yyval.ival) = strtol(yytext, NULL, 10);
					}
    break;

  case 91:

/* Line 1455 of yacc.c  */
#line 974 "parser.y"
    {
						char   *ret;
						size_t toklen = yyget_leng();
						ret = malloc(toklen + 1);
						memcpy(ret, yytext, toklen);
						ret[toklen] = '\0';

						(yyval.str) = ret;
					}
    break;

  case 92:

/* Line 1455 of yacc.c  */
#line 984 "parser.y"
    {
						char   *ret;
						size_t toklen = yyget_leng();
						ret = malloc(toklen + 1);
						memcpy(ret, yytext, toklen);
						ret[toklen] = '\0';

						(yyval.str) = ret;
					}
    break;

  case 125:

/* Line 1455 of yacc.c  */
#line 1029 "parser.y"
    {
						(yyval.str) = (yyvsp[(1) - (1)].str);
					}
    break;

  case 126:

/* Line 1455 of yacc.c  */
#line 1033 "parser.y"
    {
						char   *ret;

						dstring_append((yyvsp[(1) - (2)].dstring), (yyvsp[(2) - (2)].str));
						dstring_terminate((yyvsp[(1) - (2)].dstring));
						free((yyvsp[(2) - (2)].str));

						ret = strdup(dstring_data((yyvsp[(1) - (2)].dstring)));
						dstring_free((yyvsp[(1) - (2)].dstring));
						
						(yyval.str) = ret;
					}
    break;

  case 127:

/* Line 1455 of yacc.c  */
#line 1046 "parser.y"
    {
						(yyval.str) = NULL;
					}
    break;

  case 128:

/* Line 1455 of yacc.c  */
#line 1052 "parser.y"
    {
						SlonDString	   *dsp = (SlonDString *)malloc(sizeof(SlonDString));

						dstring_init(dsp);
						dstring_append(dsp, (yyvsp[(1) - (1)].str));
						free((yyvsp[(1) - (1)].str));

						(yyval.dstring) = dsp;
					}
    break;

  case 129:

/* Line 1455 of yacc.c  */
#line 1062 "parser.y"
    {
						dstring_append((yyvsp[(1) - (2)].dstring), (yyvsp[(2) - (2)].str));
						free((yyvsp[(2) - (2)].str));

						(yyval.dstring) = (yyvsp[(1) - (2)].dstring);
					}
    break;

  case 130:

/* Line 1455 of yacc.c  */
#line 1071 "parser.y"
    {
						(yyval.str) = strdup(yychunk);
					}
    break;

  case 131:

/* Line 1455 of yacc.c  */
#line 1076 "parser.y"
    {
						(yyval.str) = strdup(yychunk);
					}
    break;



/* Line 1455 of yacc.c  */
#line 2802 "y.tab.c"
      default: break;
    }
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
      {
	YYSIZE_T yysize = yysyntax_error (0, yystate, yychar);
	if (yymsg_alloc < yysize && yymsg_alloc < YYSTACK_ALLOC_MAXIMUM)
	  {
	    YYSIZE_T yyalloc = 2 * yysize;
	    if (! (yysize <= yyalloc && yyalloc <= YYSTACK_ALLOC_MAXIMUM))
	      yyalloc = YYSTACK_ALLOC_MAXIMUM;
	    if (yymsg != yymsgbuf)
	      YYSTACK_FREE (yymsg);
	    yymsg = (char *) YYSTACK_ALLOC (yyalloc);
	    if (yymsg)
	      yymsg_alloc = yyalloc;
	    else
	      {
		yymsg = yymsgbuf;
		yymsg_alloc = sizeof yymsgbuf;
	      }
	  }

	if (0 < yysize && yysize <= yymsg_alloc)
	  {
	    (void) yysyntax_error (yymsg, yystate, yychar);
	    yyerror (yymsg);
	  }
	else
	  {
	    yyerror (YY_("syntax error"));
	    if (yysize != 0)
	      goto yyexhaustedlab;
	  }
      }
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
	{
	  /* Return failure if at end of input.  */
	  if (yychar == YYEOF)
	    YYABORT;
	}
      else
	{
	  yydestruct ("Error: discarding",
		      yytoken, &yylval);
	  yychar = YYEMPTY;
	}
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule which action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;


      yydestruct ("Error: popping",
		  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  *++yyvsp = yylval;


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined(yyoverflow) || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
     yydestruct ("Cleanup: discarding lookahead",
		 yytoken, &yylval);
  /* Do not reclaim the symbols of the rule which action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
		  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  /* Make sure YYID is used.  */
  return YYID (yyresult);
}



/* Line 1675 of yacc.c  */
#line 1080 "parser.y"



void
yyerror(const char *msg)
{
	errlog(LOG_ERROR, "%s:%d: ERROR %s at or near %s\n", current_file,
				yylineno, msg, yytext);
	parse_errors++;
}
void

parse_error(const char *msg)
{
	errlog(LOG_ERROR, "%s:%d: ERROR %s\n", current_file,
				yylineno, msg);
	parse_errors++;
}




/*
 * Local Variables:
 *  tab-width: 4
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 */

